<?php

namespace Drupal\ohdear_integration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Ohdear integration settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ohdear_integration_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['ohdear_integration.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $ohdear_settings = $this->config('ohdear_integration.settings');
    $form['ohdear_healthcheck_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Secret provided by Oh Dear App'),
      '#description' => $this->t('Enables access of Oh Dear App to the healthcheck endpoint. Healthcheck secret is obtained from the OhDear service.'),
      '#default_value' => $ohdear_settings->get('ohdear_healthcheck_secret'),
      '#attributes' => [
        'placeholder' => '4zcke2vxfETABM8h',
      ],
    ];
    $form['ohdear_cron_uri'] = [
      '#type' => 'textfield',
      '#title' => $this->t('OhDear Cron Uri'),
      '#description' => $this->t('Uri to ping when cron is run. Monitoring scheduled tasks is running if this value is configured. Uri should be obtained from the OhDear service.'),
      '#default_value' => $ohdear_settings->get('ohdear_cron_uri') ?? '',
      '#attributes' => [
        'placeholder' => 'https://ping.ohdear.app/db4a0676-f25e-3328-b325-0d8a5c58fac1',
      ],
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('ohdear_integration.settings')
      ->set('ohdear_healthcheck_secret', $form_state->getValue('ohdear_healthcheck_secret'))
      ->set('ohdear_cron_uri', $form_state->getValue('ohdear_cron_uri'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
